@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -19,18 +19,28 @@
 
 #include "context.h"
 #include "image_filter.h"
+#include "parameters.h"
+#include "blur.h"
 
 
 u_long id = 944355799;
+uint32_t version = 0;
 u_long options = BE_BLUR;
 char desc[] = "Blur filter";
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  border_mode = BM_TOROIDAL;
+}
+
+
 void
 run(Context_t *ctx)
 {
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
 
-  image_filter_average(dst, src, FT_BLUR1_3x3, BM_TOROIDAL, 0, NULL);
+  image_filter_average(dst, src, FT_BLUR1_3x3, border_mode, 0, NULL);
 }
