@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,10 +18,12 @@
  */
 
 #include "translation.h"
+#include "parameters.h"
 
 /* we don't use Randomness in our version --oliv3 */
 
 u_long id = 1071960048;
+uint32_t version = 0;
 u_long options = BE_DISPLACE;
 char dname[] = "Space out";
 char desc[] = "Outwards space move";
@@ -34,6 +36,16 @@ static Translation_t *t_space = NULL;
 
 /* int Randomness = DEFAULT_RAND; */
 static int speed = DEFAULT_SPEED;
+static float speed_factor = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_SPEED_FACTOR, speed_factor, -0.01, 0.01);
+
+  return params;
+}
 
 
 static Map_t
@@ -64,14 +76,37 @@ cth_space(const short in_x, const short in_y)
 static void
 init_params()
 {
-  speed = b_rand_int_range(30, 100);
+  speed = speed_factor * b_rand_int_range(30, 100);
   /* Randomness = b_rand_int_range(12, 100); */
 }
 
 
+void
+set_parameters(const json_t *in_parameters)
+{
+  int reload = 0;
+  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_SPEED_FACTOR, &speed_factor, 0, 10);
+
+  if (reload) {
+    Translation_delete(t_space);
+    t_space = Translation_new(&cth_space, &init_params);
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
+
 void
 on_switch_on(Context_t *ctx)
 {
+  speed_factor = 1;
   Translation_batch_init(t_space);
 }
 
