@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "translation.h"
+#include "parameters.h"
 
 
 u_long id = 949050897;
+uint32_t version = 0;
 u_long options = BE_DISPLACE;
 char dname[] = "Spiral";
 char desc[] = "Spiral effect";
@@ -36,6 +38,17 @@ static int cx, cy;
 const float q = M_PI / 2;
 const float p = 45.0 / 180.0 * M_PI;
 
+static float p_factor = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_P_FACTOR, p_factor, -0.01, 0.01);
+
+  return params;
+}
+
 
 static Map_t
 cth_spiral(const short in_x, const short in_y)
@@ -67,8 +80,8 @@ cth_spiral(const short in_x, const short in_y)
       ang += M_PI;
     }
 
-    dx = ceil(-sin(ang-p)*dist/10.0);
-    dy = ceil(cos(ang-p)*dist/10.0);
+    dx = ceil(-sin(ang - p * p_factor) * dist / 10.0);
+    dy = ceil( cos(ang - p * p_factor) * dist / 10.0);
 
     if ((i == MINX) || (i == MAXX)) {
       dx = cx - i;
@@ -91,9 +104,32 @@ init_params()
 }
 
 
+void
+set_parameters(const json_t *in_parameters)
+{
+  int reload = 0;
+  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_P_FACTOR, &p_factor, 0, 10);
+
+  if (reload) {
+    Translation_delete(t_spiral);
+    t_spiral = Translation_new(&cth_spiral, &init_params);
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
+
 void
 on_switch_on(Context_t *ctx)
 {
+  p_factor = 1;
   Translation_batch_init(t_spiral);
 }
 
