@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -20,9 +20,10 @@
 #include "context.h"
 #include "spline.h"
 #include "particles.h"
-#include "../include/delay.h"
+#include "delay.h"
 
 u_long id = 1547584147;
+uint32_t version = 0;
 u_long options = BE_SFX3D|BEQ_PARTICLES;
 u_long mode = OVERLAY;
 char desc[] = "Stereo phase-space reconstruction with spline and particles";
