@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -20,11 +20,12 @@
 #include "context.h"
 #include "spline.h"
 #include "particles.h"
-#include "../include/delay.h"
+#include "delay.h"
 
 // #define PARTICLES
 
 u_long id = 1547656272;
+uint32_t version = 0;
 u_long options = BE_SFX3D
 #ifdef PARTICLES
                  |BEQ_PARTICLES
