@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -108,9 +108,11 @@
 /* Adapted for Le Biniou by <olivier@biniou.info> */
 
 #include "context.h"
+#include "parameters.h"
 
 u_long id = 1069709528;
 /* it's pseudo-3d */
+uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
 char desc[] = "Flow effect";
@@ -151,6 +153,57 @@ typedef struct {
 /* #define MRAND(x) (b_rand_int_range(0, x)) */
 /* #define RAND(x) (b_rand_int_range(0, x)) */
 
+#define NB_FLOW 8
+
+static void fill_flow_struct();
+
+enum Mode { MODE_SELECTED = 0, MODE_RANDOM, MODE_NB } Mode_e;
+const char *mode_list[MODE_NB] = { "Selected", "Random" };
+
+/* parameters */
+static enum Mode flow_mode = MODE_RANDOM;
+static int flow_id = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_string_list(params, BPP_MODE, MODE_NB, mode_list, flow_mode);
+  plugin_parameters_add_int(params, BPP_FLOW_ID, flow_id, -1, 1);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  int reload = 0;
+  reload |= plugin_parameter_parse_int_range(in_parameters, BPP_FLOW_ID, &flow_id, 0, NB_FLOW-1) & PLUGIN_PARAMETER_CHANGED;
+
+  int mode_idx = 0;
+  if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_MODE, MODE_NB, mode_list, &mode_idx, 0, MODE_NB-1)) {
+    flow_mode = (enum Mode)mode_idx;
+    reload = 1;
+  }
+
+  if (reload) {
+    if (flow_mode == MODE_SELECTED) {
+      fill_flow_struct();
+    }
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
+
 typedef struct {
   int         count;
   double      size;
@@ -252,26 +305,14 @@ free_flow(flowstruct *sp)
 }
 
 
-void
-on_switch_on(Context_t *ctx)
+static void
+fill_flow_struct()
 {
   flowstruct *sp;
   int         b;
   double      beemult = 1 ;
   dvector     range;
-  int rand;
 
-  /* valgrind relou test */
-  rand = NRAND(8);
-
-  b_timer_start(changeme);
-
-  /*
-    if (flows == NULL) {
-    if ((flows = xcalloc(1,sizeof(flowstruct))) == NULL)
-    return;
-    }
-  */
   sp = &flow;
   sp->count = 0;
   sp->tumble.theta = balance_rand(M_PI);
@@ -290,102 +331,102 @@ on_switch_on(Context_t *ctx)
     sp->taillen = MINTRAIL;
   }
 
-  switch (rand) {
-  case 0:
-    sp->view.depth = 10;
-    sp->view.height = 0.2;
-    beemult = 3;
-  /* fallthrough */
-  case 1:
-    sp->ODE = Lorenz;
-    sp->step = 0.02;
-    sp->size = 60;
-    sp->centre.x = 0;
-    sp->centre.y = 0;
-    sp->centre.z = 24;
-    range.x = 5;
-    range.y = 5;
-    range.z = 1;
-    sp->par.a = 10 + balance_rand(5);
-    sp->par.b = 28 + balance_rand(5);
-    sp->par.c = 2 + balance_rand(1);
-    break;
-  case 2:
-    sp->view.depth = 10;
-    sp->view.height = 0.1;
-    beemult = 4;
-  /* fallthrough */
-  case 3:
-    sp->ODE = Rossler;
-    sp->step = 0.05;
-    sp->size = 24;
-    sp->centre.x = 0;
-    sp->centre.y = 0;
-    sp->centre.z = 3;
-    range.x = 6;
-    range.y = 6;
-    range.z = 5;
-    sp->par.a = 2 + balance_rand(1);
-    sp->par.b = 0.2 + balance_rand(0.1);
-    sp->par.c = 0.2 + balance_rand(0.1);
-    break;
-  case 4:
-    sp->view.depth = 10;
-    sp->view.height = 0.1;
-    beemult = 3;
-  /* fallthrough */
-  case 5:
-    sp->ODE = RosslerCone;
-    sp->step = 0.05;
-    sp->size = 24;
-    sp->centre.x = 0;
-    sp->centre.y = 0;
-    sp->centre.z = 3;
-    range.x = 6;
-    range.y = 6;
-    range.z = 6;
-    sp->par.a = 2;
-    sp->par.b = 0.2;
-    sp->par.c = 0.331 + balance_rand(0.01);
-    break;
-  case 6:
-    sp->ODE = Birkhoff;
-    sp->step = 0.04;
-    sp->size = 2.6;
-    sp->centre.x = 0;
-    sp->centre.y = 0;
-    sp->centre.z = 0;
-    range.x = 3;
-    range.y = 4;
-    range.z = 0;
-    sp->par.a = 10 + balance_rand(5);
-    sp->par.b = 0.35 + balance_rand(0.25);
-    sp->par.c = 1.57;
-    sp->tumble.theta = 0;
-    sp->tumble.phi = 0;
-    sp->tumble.dtheta = 0;
-    sp->tumble.dphi = 0;
-    break;
-  case 7:
-  default:
-    sp->ODE = Duffing;
-    sp->step = 0.02;
-    sp->size = 30;
-    sp->centre.x = 0;
-    sp->centre.y = 0;
-    sp->centre.z = 0;
-    range.x = 20;
-    range.y = 20;
-    range.z = 0;
-    sp->par.a = 0.2 + balance_rand(0.1);
-    sp->par.b = 27.0 + balance_rand(3.0);
-    sp->par.c = 1.33;
-    sp->tumble.theta = 0;
-    sp->tumble.phi = 0;
-    sp->tumble.dtheta = -NRAND(2)*sp->par.c*sp->step;
-    sp->tumble.dphi = 0;
-    beemult = 0.5;
-    break;
+  switch (flow_id) {
+    case 0:
+      sp->view.depth = 10;
+      sp->view.height = 0.2;
+      beemult = 3;
+    /* fallthrough */
+    case 1:
+      sp->ODE = Lorenz;
+      sp->step = 0.02;
+      sp->size = 60;
+      sp->centre.x = 0;
+      sp->centre.y = 0;
+      sp->centre.z = 24;
+      range.x = 5;
+      range.y = 5;
+      range.z = 1;
+      sp->par.a = 10 + balance_rand(5);
+      sp->par.b = 28 + balance_rand(5);
+      sp->par.c = 2 + balance_rand(1);
+      break;
+    case 2:
+      sp->view.depth = 10;
+      sp->view.height = 0.1;
+      beemult = 4;
+    /* fallthrough */
+    case 3:
+      sp->ODE = Rossler;
+      sp->step = 0.05;
+      sp->size = 24;
+      sp->centre.x = 0;
+      sp->centre.y = 0;
+      sp->centre.z = 3;
+      range.x = 6;
+      range.y = 6;
+      range.z = 5;
+      sp->par.a = 2 + balance_rand(1);
+      sp->par.b = 0.2 + balance_rand(0.1);
+      sp->par.c = 0.2 + balance_rand(0.1);
+      break;
+    case 4:
+      sp->view.depth = 10;
+      sp->view.height = 0.1;
+      beemult = 3;
+    /* fallthrough */
+    case 5:
+      sp->ODE = RosslerCone;
+      sp->step = 0.05;
+      sp->size = 24;
+      sp->centre.x = 0;
+      sp->centre.y = 0;
+      sp->centre.z = 3;
+      range.x = 6;
+      range.y = 6;
+      range.z = 6;
+      sp->par.a = 2;
+      sp->par.b = 0.2;
+      sp->par.c = 0.331 + balance_rand(0.01);
+      break;
+    case 6:
+      sp->ODE = Birkhoff;
+      sp->step = 0.04;
+      sp->size = 2.6;
+      sp->centre.x = 0;
+      sp->centre.y = 0;
+      sp->centre.z = 0;
+      range.x = 3;
+      range.y = 4;
+      range.z = 0;
+      sp->par.a = 10 + balance_rand(5);
+      sp->par.b = 0.35 + balance_rand(0.25);
+      sp->par.c = 1.57;
+      sp->tumble.theta = 0;
+      sp->tumble.phi = 0;
+      sp->tumble.dtheta = 0;
+      sp->tumble.dphi = 0;
+      break;
+    case 7:
+    default:
+      sp->ODE = Duffing;
+      sp->step = 0.02;
+      sp->size = 30;
+      sp->centre.x = 0;
+      sp->centre.y = 0;
+      sp->centre.z = 0;
+      range.x = 20;
+      range.y = 20;
+      range.z = 0;
+      sp->par.a = 0.2 + balance_rand(0.1);
+      sp->par.b = 27.0 + balance_rand(3.0);
+      sp->par.c = 1.33;
+      sp->tumble.theta = 0;
+      sp->tumble.phi = 0;
+      sp->tumble.dtheta = -NRAND(2)*sp->par.c*sp->step;
+      sp->tumble.dphi = 0;
+      beemult = 0.5;
+      break;
   }
 
   if (sp) {
@@ -404,14 +445,21 @@ on_switch_on(Context_t *ctx)
   }
 
   /* Initialize point positions, velocities, etc. */
-
   for (b = 0; b < sp->beecount; b++) {
     X(1, b) = X(0, b) = balance_rand(range.x);
     Y(1, b) = Y(0, b) = balance_rand(range.y);
     Z(1, b) = Z(0, b) = balance_rand(range.z);
   }
+}
 
-  /* printf("+++ flow::on_switch_on() done\n"); */
+
+void
+on_switch_on(Context_t *ctx)
+{
+  flow_id = NRAND(NB_FLOW);
+  fill_flow_struct();
+
+  b_timer_start(changeme);
 }
 
 
@@ -472,7 +520,6 @@ run(Context_t *ctx)
     M[2][0]= 0;
     M[2][1]= 0;
     M[2][2]= 0;
-
   }
 
   for (col = 0; col < NCOL; col++) {
@@ -629,7 +676,7 @@ run(Context_t *ctx)
 
   if(++sp->count > 512)*/
   ++sp->count;
-  if (b_timer_elapsed(changeme) > 30) {
+  if (flow_mode == MODE_RANDOM && b_timer_elapsed(changeme) > 30) {
     on_switch_on(ctx);
   }
 }
