@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -19,9 +19,11 @@
 
 #include "context.h"
 #include "images.h"
+#include "parameters.h"
 
 
 u_long id = 1216566743;
+uint32_t version = 0;
 u_long options = BE_GFX|BE_SFX2D|BEQ_IMAGE;
 u_long mode = OVERLAY;
 char desc[] = "Pulse pictures";
@@ -31,10 +33,40 @@ char desc[] = "Pulse pictures";
 
 static const Image8_t *pic = NULL;
 
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
 
 void
 on_switch_on(Context_t *ctx)
 {
+  /* Initialize parameters */
+  volume_scale = 1;
+
   pic = Images_random(images);
 }
 
@@ -48,7 +80,7 @@ run(Context_t *ctx)
   u_long p, k;
 
   img = pic->buff;
-  volume = Input_get_volume(ctx->input);
+  volume = Input_get_volume(ctx->input) * volume_scale;
   //volume = expf(volume)/expf(1.0);
   // printf("Vol= %f\n", volume);
   p = (u_long)(volume * BUFFSIZE  * 1);
