@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -20,6 +20,35 @@
 #ifndef __SPECTRUM_H
 #define __SPECTRUM_H
 
+#include "parameters.h"
+
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
+
+
+json_t *
+parameters(json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
 
 static inline u_short
 float_to_ushort(float x, u_short minval, u_short maxval)
