@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,13 +18,50 @@
  */
 
 #include "context.h"
+#include "parameters.h"
 
 u_long id = 1073678364;
+uint32_t version = 0;
 u_long options = BE_SFX3D|BEQ_NORANDOM;
 char dname[] = "OF A-Spiral";
 u_long mode = OVERLAY;
 char desc[] = "3D Archimedean spiral";
 
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 1);
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
+
+
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 1;
+}
+
 
 void
 run(Context_t *ctx)
@@ -34,7 +71,7 @@ run(Context_t *ctx)
 
   Buffer8_clear(dst);
 
-  float random = Input_get_volume(ctx->input);
+  float random = Input_get_volume(ctx->input) * volume_scale;
 
   for (t = 0 ; t < 8 * M_PI ; t += 0.1) {
     Point3d_t P;
