@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "oscillo.h"
+#include "parameters.h"
 
 
 u_long id = 946482114;
+uint32_t version = 0;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Draw an oscillo in a radar way";
@@ -32,7 +34,34 @@ static Point2d_t last_polar;
 static float     polar_theta, polar_inc_theta;
 static u_short   polar_radius;
 static float     polar_length;
-static int       connect = 1;
+static int       polaroscillo_connect = 1;
+
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 
 void
@@ -45,7 +74,7 @@ init(const Input_t *input)
 
   P->origin = last_polar;
 
-  t.v_j_factor = MAXY/4 * 0.85;
+  t.v_j_factor = MAXY/4 * volume_scale;
 
   polar_inc_theta = 2. * M_PI * polar_length / (float)(input->size);
 
@@ -98,10 +127,18 @@ destroy(Context_t *ctx)
 }
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 0.85;
+}
+
+
 void
 run(Context_t *ctx)
 {
   Buffer8_clear(passive_buffer(ctx));
-  Porteuse_draw(P, ctx, connect);
+  Porteuse_draw(P, ctx, polaroscillo_connect);
   init(ctx->input);
 }
