@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "oscillo.h"
+#include "parameters.h"
 
 
 u_long id = 946482109;
+uint32_t version = 0;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Rotating oscilloscope";
@@ -32,7 +34,37 @@ static Porteuse_t *P = NULL;
 #define RADIUS (HMINSCREEN * 0.85)
 
 static float alpha = 0.0;
-static int   connect = 1;
+static int   roscillo_connect = 1;
+
+static float volume_scale = 0;
+static float speed = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+  plugin_parameters_add_double(params, BPP_SPEED, speed, -0.2, 0.2);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+  plugin_parameter_parse_float_range(in_parameters, BPP_SPEED, &speed, -100, 100);
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 
 static void
@@ -46,7 +78,7 @@ init()
   P->origin.x = CENTERX - RADIUS * cos (alpha);
   P->origin.y = CENTERY - RADIUS * sin (alpha);
 
-  t.v_j_factor = HMAXY * 0.85;
+  t.v_j_factor = HMAXY * volume_scale;
   t.v_i.x = (2.0 / (float)(P->size - 1) * (float)RADIUS) * cos (alpha);
   t.v_i.y = (2.0 / (float)(P->size - 1) * (float)RADIUS) * sin (alpha);
 
@@ -80,6 +112,9 @@ destroy(Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
+  /* Initialize parameters */
+  volume_scale = 0.85;
+  speed = 1;
   /* connect = b_rand_boolean(); */
 }
 
@@ -88,10 +123,10 @@ void
 run(Context_t *ctx)
 {
   Buffer8_clear(passive_buffer(ctx));
-  Porteuse_draw(P, ctx, connect);
+  Porteuse_draw(P, ctx, roscillo_connect);
 
   /* FIXME hardcoded */
-  alpha += 0.005;
+  alpha += 0.005 * speed;
 
   if (alpha > 2*M_PI) {
     alpha -= 2*M_PI;
