@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,8 +24,10 @@
  */
 
 #include "context.h"
+#include "parameters.h"
 
 u_long id = 949178536;
+uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
 char desc[] = "Rotors effect";
@@ -56,7 +58,7 @@ typedef struct Rotor {
 
 static _Complex float ci;
 static float min_rnd_factor, max_rnd_factor;
-static u_short length, nb_rotors, min_color, max_color;
+static u_short nb_rotors, min_color, max_color;
 static float freq_base_moy, freq_base_ect;
 static float freq_var_moy, freq_var_ect;
 static float ampl_var_moy, ampl_var_ect;
@@ -66,6 +68,50 @@ static int max_prof;
 static Rotor tab[MAX_ROTORS];
 static float time_step;
 
+static int nb_min_rotors = 0;
+static int length = 0;
+static float speed = 0;
+static float scale = 0;
+
+static void post_init();
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_int(params, BPP_NB_MIN_ROTORS, nb_min_rotors, -1, 1);
+  plugin_parameters_add_double(params, BPP_PROBA_VISIBLE, proba_visible, -0.01, 0.01);
+  plugin_parameters_add_int(params, BPP_LENGTH, length, -10, 10);
+  plugin_parameters_add_double(params, BPP_SPEED, speed, -0.01, 0.01);
+  plugin_parameters_add_double(params, BPP_SCALE, scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  int reload = 0;
+  reload |= plugin_parameter_parse_int_range(in_parameters, BPP_NB_MIN_ROTORS, &nb_min_rotors, 0, 1) & PLUGIN_PARAMETER_CHANGED;
+  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_PROBA_VISIBLE, &proba_visible, 0, 1) & PLUGIN_PARAMETER_CHANGED;
+  plugin_parameter_parse_int_range(in_parameters, BPP_LENGTH, &length, 10, 1000);
+  plugin_parameter_parse_float_range(in_parameters, BPP_SPEED, &speed, -10, 10);
+  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_SCALE, &scale, 0, 2) & PLUGIN_PARAMETER_CHANGED;
+
+  if (reload) {
+    post_init();
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 /* note: this is _NOT_ a perfect binary-tree,
  * ie a node might have 1 or 2 sons
@@ -143,7 +189,7 @@ static void
 build()
 {
   build_rotor_tree();
-  init_rotor_tree(tab, MINSCREEN);
+  init_rotor_tree(tab, scale * MINSCREEN);
 }
 
 
@@ -172,7 +218,7 @@ norm_freq_base()
 
 
 static inline Pixel_t
-couleur()
+color()
 {
   float d = drand48() * (max_color - min_color) + min_color;
   return (Pixel_t)d;
@@ -194,6 +240,21 @@ set_random_visible()
     }
   }
   VERBOSE(printf(" done\n"));
+
+  /* Setting at least 1 rotor, if asked */
+  if (nb_min_rotors == 1) {
+    uint8_t n_visible = 0;
+    for (i = 7; i < MAX_ROTORS; i++)
+      if (tab[i].visible) {
+        n_visible++;
+      }
+
+    if (n_visible == 0) {
+      uint8_t v = b_rand_int_range(7, MAX_ROTORS-1);
+      VERBOSE(printf("set %d visible\n", v));
+      tab[v].visible = 1;
+    }
+  }
 }
 
 
@@ -203,7 +264,7 @@ post_init()
   int i;
 
   for (i = 0; i < nb_rotors; i++)  {
-    tab[i].coul      = couleur();
+    tab[i].coul      = color();
     tab[i].freq      = norm_freq_base();
     tab[i].freq_var  = norm_freq();
     tab[i].ampl_var  = norm_ampl();
@@ -222,7 +283,6 @@ create(Context_t *ctx)
   /* printf("Rotors:  %f+%f*i\n", creal(ci), cimag(ci)); */
 
   nb_rotors = 16;
-  length = 200;
   min_color = 200;
   max_color = 250;
   min_rnd_factor = 0.3;
@@ -249,8 +309,7 @@ refresh(Rotor *rotor)
     float f, arg, alpha;
     _Complex float pos_rel;
 
-    f = rotor->freq
-        * exp(rotor->ampl_var * cos(2 * M_PI * rotor->freq_var * rotor_time));
+    f = rotor->freq * exp(rotor->ampl_var * cos(2 * M_PI * rotor->freq_var * rotor_time));
     arg = f * rotor_time;
     arg -= (long)(arg);
     alpha = 2 * M_PI * arg;
@@ -281,7 +340,6 @@ display(Context_t *ctx)
       short x, y;
       x = (short)(creal(tab[i].centre) + CENTERX);
       y = (short)(cimag(tab[i].centre) + CENTERY);
-      /*      printf ("x= %d\ty= %d\n", x, y);*/
 
 #if 1
       set_pixel(dst, x, y, tab[i].coul);
@@ -299,7 +357,7 @@ run(Context_t *ctx)
   Buffer8_clear(passive_buffer(ctx));
 
   for (i = 0; i < length; i++) {
-    rotor_time += time_step;
+    rotor_time += time_step * speed;
     refresh(tab);
     display(ctx);
   }
@@ -328,5 +386,10 @@ run(Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
+  nb_min_rotors = 1;
+  proba_visible = 0.33;
+  length = 200;
+  speed = 1;
+  scale = 1;
   post_init();
 }
