@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "oscillo.h"
+#include "parameters.h"
 
 
 u_long id = 946482113;
+uint32_t version = 0;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Oscilloscope based on a sine-wave";
@@ -35,7 +37,35 @@ static float sin2_phi = 0;
 static float sin2_freq;        /* initialized on create */
 static float sin2_target_freq; /* initialized on create */
 static float sin2_freq_inc;    /* initialized on create */
-static int   connect = 1;
+static int   sin2oscillo_connect = 1;
+
+
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 
 static inline float
@@ -85,7 +115,7 @@ init(Context_t *ctx)
   P->origin.x = 1;
   P->origin.y = HMAXY;
 
-  t.v_j_factor = HMAXY / 2 * .85;
+  t.v_j_factor = HMAXY / 2 * volume_scale;
 
   for (i = 0; i < P->size; i++) {
     float y = (t.v_j_factor
@@ -127,11 +157,19 @@ destroy(Context_t *ctx)
 }
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 0.85;
+}
+
+
 void
 run(Context_t *ctx)
 {
   Buffer8_clear(passive_buffer(ctx));
-  Porteuse_draw(P, ctx, connect);
+  Porteuse_draw(P, ctx, sin2oscillo_connect);
   change_params();
   init(ctx);
 }
