@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,10 +18,11 @@
  */
 
 #include "context.h"
-#include "../include/spectrum.h"
+#include "spectrum.h"
 
 
 u_long id = 1051738767;
+uint32_t version = 0;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Display the spectrum";
@@ -30,6 +31,14 @@ char desc[] = "Display the spectrum";
 static u_short *v_start = NULL, *v_end = NULL;
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 1;
+}
+
+
 int8_t
 create(Context_t *ctx)
 {
@@ -70,7 +79,7 @@ run(Context_t *ctx)
   for (i = 1; i < ctx->input->spectrum_size; i++) {
     u_short top, ye;
 
-    top = float_to_nearest_ushort(MAXY * ctx->input->spectrum_log[A_MONO][i], 0, MAXY);
+    top = float_to_nearest_ushort(MAXY * ctx->input->spectrum_log[A_MONO][i] * volume_scale, 0, MAXY);
     for (ye = 0; ye < top; ye++) {
       Pixel_t color = (Pixel_t)floor((float)ye / top * 255.0);
       h_line_nc(dst, ye, v_start[i], v_end[i], color);
