@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,6 +18,8 @@
  */
 
 #include "context.h"
+#include "parameters.h"
+#include "gum.h"
 
 /* TODO optimize
  * we can precompute an array for the "idx" variable
@@ -26,11 +28,11 @@
  */
 
 u_long id = 1074631868;
+uint32_t version = 0;
 u_long options = BE_LENS|BEQ_HOR;
 char dname[] = "X gum";
 char desc[] = "Gum effect";
 
-
 static inline void
 gum(Context_t *ctx, u_short x, u_short max_y)
 {
@@ -58,11 +60,19 @@ gum(Context_t *ctx, u_short x, u_short max_y)
 static inline void
 do_gum(Context_t *ctx, u_short x, float val)
 {
-  u_short max_y = HHEIGHT + val * HHEIGHT;
+  u_short max_y = HHEIGHT + val * volume_scale * HHEIGHT;
   gum(ctx, x, max_y);
 }
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 1;
+}
+
+
 void
 run(Context_t *ctx)
 {
