@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "oscillo.h"
+#include "parameters.h"
 
 
 u_long id = 946482110;
+uint32_t version = 0;
 u_long options = BE_SFX2D|BEQ_HOR;
 char dname[] = "X oscillo";
 u_long mode = OVERLAY;
@@ -28,7 +30,25 @@ char desc[] = "Horizontal mono oscilloscope";
 
 
 static Porteuse_t *P = NULL;
-static int connect = 1;
+static int xoscillo_connect = 1;
+
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
 
 
 static void
@@ -42,7 +62,7 @@ init()
   P->origin.x = 0;
   P->origin.y = CENTERY;
 
-  t.v_j_factor = HMAXY * 0.85;
+  t.v_j_factor = HMAXY * volume_scale;
   t.v_i.x = 1.0 / (float)(P->size - 1) * (float)MAXX;
 
   for (i = 0; i < P->size; i++) {
@@ -53,6 +73,27 @@ init()
 }
 
 
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+  if(in_parameters) {
+    init();
+  }
+
+  return get_parameters();
+}
+
+
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 0.85;
+  init();
+}
+
+
 int8_t
 create(Context_t *ctx)
 {
@@ -76,5 +117,5 @@ void
 run(Context_t *ctx)
 {
   Buffer8_clear(passive_buffer(ctx));
-  Porteuse_draw(P, ctx, connect);
+  Porteuse_draw(P, ctx, xoscillo_connect);
 }
