@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,9 +18,11 @@
  */
 
 #include "oscillo.h"
+#include "parameters.h"
 
 
 u_long id = 1089152274;
+uint32_t version = 0;
 u_long options = BE_SFX2D|BEQ_HOR;
 char dname[] = "X oscillo stereo";
 u_long mode = OVERLAY;
@@ -28,7 +30,25 @@ char desc[] = "Horizontal stereo oscilloscope";
 
 
 static Porteuse_t *PL = NULL, *PR = NULL;
-static int connect = 1;
+static int xoscillo_s_connect = 1;
+
+static float volume_scale = 0;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+}
 
 
 static void
@@ -44,7 +64,7 @@ init()
   PL->origin.y = HHEIGHT/2;
   PR->origin.y = MAXY-HHEIGHT/2;
 
-  t.v_j_factor = HMAXY * 0.85;
+  t.v_j_factor = HMAXY * volume_scale;
   t.v_i.x = 1.0 / (float)(PL->size - 1) * (float)MAXX;
 
   for (i = 0; i < PL->size; i++) {
@@ -67,9 +87,25 @@ create(Context_t *ctx)
 }
 
 
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+  if(in_parameters) {
+    init();
+  }
+
+  return get_parameters();
+}
+
+
 void
 on_switch_on(Context_t *ctx)
 {
+  /* Initialize parameters */
+  volume_scale = 0.85;
+  init();
+
   /* connect = b_rand_boolean(); */
 }
 
@@ -88,6 +124,6 @@ void
 run(Context_t *ctx)
 {
   Buffer8_clear(passive_buffer(ctx));
-  Porteuse_draw(PL, ctx, connect);
-  Porteuse_draw(PR, ctx, connect);
+  Porteuse_draw(PL, ctx, xoscillo_s_connect);
+  Porteuse_draw(PR, ctx, xoscillo_s_connect);
 }
