@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,14 +18,23 @@
  */
 
 #include "context.h"
-#include "../include/shaker.h"
+#include "shaker.h"
 
 u_long id = 947072847;
+uint32_t version = 0;
 u_long options = BE_LENS;
 char dname[] = "Y Shaker";
 char desc[] = "Shaker effect";
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  /* Initialize parameters */
+  volume_scale = 1;
+}
+
+
 void
 run(Context_t *ctx)
 {
@@ -41,8 +50,8 @@ run(Context_t *ctx)
     uint16_t i;
 
     for (i = 0; i < WIDTH; i++) {
-      char dx = Input_clamp(ctx->input->data[A_LEFT][idx])  * SOUND_DISTURB_K;
-      char dy = Input_clamp(ctx->input->data[A_RIGHT][idx]) * SOUND_DISTURB_K;
+      char dx = Input_clamp(ctx->input->data[A_LEFT][idx])  * volume_scale * SOUND_DISTURB_K;
+      char dy = Input_clamp(ctx->input->data[A_RIGHT][idx]) * volume_scale * SOUND_DISTURB_K;
 
       if (++idx == ctx->input->size) {
         idx = 0;
