@@ -1,6 +1,6 @@
 /*
- *  Copyright 2014-2019 Frantz Balinski
- *  Copyright 2018-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 2014-2020 Frantz Balinski
  *
  *  This file is part of lebiniou.
  *
@@ -24,14 +24,54 @@
  */
 
 #include "context.h"
+#include "parameters.h"
 
 
 u_long id = 1410477171;
+uint32_t version = 0;
 u_long options = BE_BLUR|BEQ_NORANDOM;
 char desc[] = "Color fade-out effect";
 
 
 static float decay;
+enum Mode { MODE_SELECTED = 0, MODE_RANDOM, MODE_NB } Mode_e;
+const char *mode_list[MODE_NB] = { "Selected", "Random" };
+
+/* parameters */
+static enum Mode mode = MODE_RANDOM;
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_string_list(params, BPP_MODE, MODE_NB, mode_list, mode);
+  plugin_parameters_add_double(params, BPP_DECAY, decay, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  int mode_idx = 0;
+  if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_MODE, MODE_NB, mode_list, &mode_idx, 0, MODE_NB-1)) {
+    mode = (enum Mode)mode_idx;
+  }
+
+  if (mode == MODE_SELECTED) {
+    plugin_parameter_parse_float_range(in_parameters, BPP_DECAY, &decay, 0, 1);
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 
 void
@@ -62,6 +102,7 @@ run(Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
+  mode = MODE_RANDOM;
   decay = (float) pow(2, b_rand_double_range(log2(1), log2(31)));
   decay = decay / (decay + 1.f);
 #ifdef DEBUG
