@@ -1,7 +1,7 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
- *  Copyright 2014-2019 Frantz Balinski
- *  Copyright 2019 Laurent Marsac
+ *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 2014-2020 Frantz Balinski
+ *  Copyright 2019-2020 Laurent Marsac
  *
  *  This file is part of lebiniou.
  *
@@ -21,9 +21,11 @@
 
 #include "constants.h"
 #include "context.h"
+#include "parameters.h"
 
 
 u_long id = 1177412508;
+uint32_t version = 0;
 u_long options = BE_SFX2D;
 u_long mode = OVERLAY;
 char desc[] = "Zebulon effect";
@@ -40,13 +42,8 @@ typedef struct position {
   uint16_t x, y;
 } POSITION;
 
-#define NB_SPHERES 24
-
-/* radius max: HEIGHT / 24 */
-#define RADIUS(h) ((h)/24)
-
 /* spheres centres */
-static POSITION centres[NB_SPHERES];
+static POSITION *centres = NULL;
 
 /* sphere radius */
 static uint16_t radius;
@@ -58,14 +55,71 @@ static uint16_t radius_max;
 static uint16_t size_max;
 
 /* color indices grid */
-static Pixel_t *color_indices;
+static Pixel_t *color_indices = NULL;
+
+/* parameters */
+static int nb_spheres = 0;
+static float radius_factor = 0; /* sets radius max */
+static float volume_scale = 0;
+static float sensibility = 0;
+static float move_factor = 1;
+static float border_x = 0; /* border will be set to border_x * HWIDTH */
+static float border_y = 0; /* border will be set to border_y * HHEIGHT */
+
+static void free_spheres();
+static void move_spheres();
+
+json_t *
+get_parameters()
+{
+  json_t *params = json_object();
+  plugin_parameters_add_int(params, BPP_NB_SPHERES, nb_spheres, -1, 1);
+  plugin_parameters_add_double(params, BPP_RADIUS_FACTOR, radius_factor, -0.01, 0.01);
+  plugin_parameters_add_double(params, BPP_VOLUME_SCALE, volume_scale, -0.01, 0.01);
+  plugin_parameters_add_double(params, BPP_SENSITIVITY, sensibility, -0.1, 0.1);
+  plugin_parameters_add_double(params, BPP_MOVE_FACTOR, move_factor, -0.1, 0.1);
+  plugin_parameters_add_double(params, BPP_BORDER_X, border_x, -0.01, 0.01);
+  plugin_parameters_add_double(params, BPP_BORDER_Y, border_y, -0.01, 0.01);
+
+  return params;
+}
+
+
+void
+set_parameters(const json_t *in_parameters)
+{
+  int reload = 0;
+  reload |= plugin_parameter_parse_int_range(in_parameters, BPP_NB_SPHERES, &nb_spheres, 1, 64) & PLUGIN_PARAMETER_CHANGED;
+  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_RADIUS_FACTOR, &radius_factor, 0, 0.24) & PLUGIN_PARAMETER_CHANGED;
+  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+  plugin_parameter_parse_float_range(in_parameters, BPP_SENSITIVITY, &sensibility, 0, 10);
+  plugin_parameter_parse_float_range(in_parameters, BPP_MOVE_FACTOR, &move_factor, 0, 10);
+  plugin_parameter_parse_float_range(in_parameters, BPP_BORDER_X, &border_x, 0, 1);
+  plugin_parameter_parse_float_range(in_parameters, BPP_BORDER_Y, &border_y, 0, 1);
+
+  if (reload) {
+    move_spheres();
+  }
+}
+
+
+json_t *
+parameters(const json_t *in_parameters)
+{
+  set_parameters(in_parameters);
+
+  return get_parameters();
+}
 
 
 inline static void
-alloc_sphere()
+init_sphere()
 {
+  free_spheres();
+  centres = (POSITION *)xcalloc(nb_spheres, sizeof(POSITION));
+
   /* max radius for this screen size */
-  radius_max = (uint16_t) RADIUS(HEIGHT);
+  radius_max = (uint16_t)(radius_factor * HEIGHT);
   /* buffer size */
   size_max = (radius_max << 1) + 1;
   /* Allocate buffer */
@@ -75,16 +129,17 @@ alloc_sphere()
 
 
 inline static void
-free_sphere()
+free_spheres()
 {
   xfree(color_indices);
+  xfree(centres);
 }
 
 
 inline static void
 compute_radius(Context_t *ctx)
 {
-  float volume = Input_get_volume(ctx->input);
+  float volume = volume_scale * Input_get_volume(ctx->input);
 
   /** Volume ajustement **/
   /* pow(volume, X) modify plugin sensibility:
@@ -93,13 +148,11 @@ compute_radius(Context_t *ctx)
    * X > 1: "decrease" the effect (less sensitive on small volumes and better on beats)
    */
   /* and "* 50.0" to reajust global volume, otherwise spheres are too small */
-  volume = powf(volume, 3) * 50.0;
+  volume = powf(volume, sensibility) * 50.0;
 
   /* sphere radius */
   radius = (uint16_t)(volume * radius_max);
-  if (radius > radius_max) {
-    radius = radius_max;
-  }
+  radius = MIN(radius, radius_max);
 }
 
 
@@ -137,10 +190,11 @@ compute_index()
 inline static void
 move_spheres()
 {
-  uint16_t i, *p;
+  init_sphere();
 
-  p = (uint16_t *)centres;
-  for (i = 0; i < NB_SPHERES; i++) {
+  uint16_t i;
+  uint16_t *p = (uint16_t *)centres;
+  for (i = 0; i < nb_spheres; i++) {
     *p++ = 2*radius_max + (uint16_t)(b_rand_int() % (WIDTH - 4*radius_max));
     *p++ = 2*radius_max + (uint16_t)(b_rand_int() % (HEIGHT - 4*radius_max));
   }
@@ -181,18 +235,21 @@ plot_spheres(Context_t *ctx)
   Buffer8_clear(dst);
 
   /* max sphere move: +/- (radius/4) */
-  offset = radius / 4;
+  offset = radius * move_factor / 4;
   length = offset * 2 + 1;
 
+  uint16_t border_offset_x = MAX(2 * radius_max, border_x * HWIDTH);
+  uint16_t border_offset_y = MAX(2 * radius_max, border_y * HHEIGHT);
+
   p = (uint16_t *)centres;
-  for (i = 0; i < NB_SPHERES; i++) {
+  for (i = 0; i < nb_spheres; i++) {
     plot_sphere(dst, (POSITION *)p);
 
     /* Move sphere */
     n = *p;
-    *p++ = MAX( 2 * radius_max, MIN( (uint16_t) ((n + WIDTH  + (b_rand_int() % length) - offset) % WIDTH), WIDTH - 2 * radius_max));
+    *p++ = MAX( border_offset_x, MIN( (uint16_t) ((n + WIDTH  + (b_rand_int() % length) - offset) % WIDTH), WIDTH - border_offset_x));
     n = *p;
-    *p++ = MAX( 2 * radius_max, MIN( (uint16_t) ((n + HEIGHT + (b_rand_int() % length) - offset) % HEIGHT), HEIGHT - 2 * radius_max));
+    *p++ = MAX( border_offset_y, MIN( (uint16_t) ((n + HEIGHT + (b_rand_int() % length) - offset) % HEIGHT), HEIGHT - border_offset_y));
   }
 }
 
@@ -200,9 +257,7 @@ plot_spheres(Context_t *ctx)
 int8_t
 create(Context_t *ctx)
 {
-  alloc_sphere();
   move_spheres();
-
   return 1;
 }
 
@@ -219,6 +274,15 @@ run(Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
+  /* Initialize parameters */
+  nb_spheres = 16;
+  radius_factor = 0.04;
+  volume_scale = 1;
+  sensibility = 3;
+  move_factor = 1;
+  border_x = 0;
+  border_y = 0;
+
   move_spheres();
 }
 
@@ -226,5 +290,5 @@ on_switch_on(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  free_sphere();
+  free_spheres();
 }
