@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -54,6 +54,14 @@ b_timer_stop(BTimer_t *timer)
 }
 
 
+void
+b_timer_restart(BTimer_t *timer)
+{
+  b_timer_stop(timer);
+  b_timer_start(timer);
+}
+
+
 float
 b_timer_elapsed(BTimer_t *timer)
 {
