@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -54,7 +54,6 @@ static pthread_t thr[MAX_CAMS];
 
 #define MAX_TRIES 5
 
-
 static void
 Context_open_webcam(Context_t *ctx)
 {
@@ -380,6 +379,12 @@ Context_set(Context_t *ctx)
     if (p->on_switch_on != NULL) {
       p->on_switch_on(ctx);
     }
+
+    if (p->parameters != NULL) {
+      /* Todo: check and use returned parameters ? */
+      json_decref(p->parameters(layer->plugin_parameters));
+    }
+
     tmp = g_list_next(tmp);
   }
 
@@ -809,3 +814,38 @@ Context_mix_buffers(const Context_t *ctx, Buffer8_t *buffs[2])
     *d = buffs[*random]->buffer[i];
   }
 }
+
+
+/* ulfius */
+#ifdef WITH_ULFIUS
+void
+Context_start_ulfius(Context_t *ctx)
+{
+  // Initialize instance with the port number
+  if (ulfius_init_instance(&ctx->instance, ULFIUS_PORT, NULL, NULL) != U_OK) {
+    xerror("ulfius_init_instance error, abort\n");
+  }
+
+  // Endpoint list declaration
+  // GET
+  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_PARAMETERS, 0, &callback_get_parameters, NULL);
+  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_SEQUENCE, 0, &callback_get_sequence, ctx);
+  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_STATISTICS, 0, &callback_get_statistics, ctx);
+  // POST
+  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_POST, NULL, BULFIUS_PARAMETERS, 0, &callback_post_parameters, NULL);
+
+  // Start the framework
+  if (ulfius_start_framework(&ctx->instance) == U_OK) {
+    VERBOSE(printf("[i] Started ulfius framework on port %d\n", ctx->instance.port));
+  } else {
+    xerror("Error starting ulfius framework\n");
+  }
+}
+
+
+void Context_stop_ulfius(Context_t *ctx)
+{
+  ulfius_stop_framework(&ctx->instance);
+  ulfius_clean_instance(&ctx->instance);
+}
+#endif
