@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,6 +32,9 @@
 #include "alarm.h"
 #include "brandom.h"
 #include "buffer_RGBA.h"
+#ifdef WITH_ULFIUS
+#include "bulfius.h"
+#endif
 
 #define NFPS     25 /* to get mean fps */
 
@@ -166,6 +169,11 @@ typedef struct Context_s {
 
   /* used to randomly mix buffers */
   Buffer8_t *random;
+
+  /* ulfius */
+#ifdef WITH_ULFIUS
+  struct _u_instance instance;
+#endif
 } Context_t;
 
 
@@ -282,4 +290,9 @@ double Context_get_volume_scale(const Context_t *);
 
 void Context_mix_buffers(const Context_t *, Buffer8_t *[2]);
 
+#ifdef WITH_ULFIUS
+void Context_start_ulfius(Context_t *);
+void Context_stop_ulfius(Context_t *);
+#endif
+
 #endif /* __BINIOU_CONTEXT_H */
