@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -30,7 +30,7 @@ float phase = 1.0;
    There is no best value, but 4 peaks/second is reasonable compromise
    before rewriting this system properly. */
 #define PEAKS_PER_SECOND 4   /* how many peaks we try to find */
-#define PEAK_COUNT_ON_HISTORY (HISTORY_SIZE / PEAKS_PER_SECOND) 
+#define PEAK_COUNT_ON_HISTORY (HISTORY_SIZE / PEAKS_PER_SECOND)
 
 /* history ring buffer for peak detection */
 static double history_buff[3][HISTORY_SIZE] = { { 0 } };
@@ -404,7 +404,7 @@ Input_process(Input_t *input)
     count = 0;
     for (i = 0; i < j; i++) {
       if (peak_val[i] >
-         (input->average + (input->maxpeak - input->average) * limit)) {
+          (input->average + (input->maxpeak - input->average) * limit)) {
         count++;
       }
     }
@@ -473,8 +473,9 @@ Input_volume_downscale(Input_t *input)
 double
 compute_avg_abs(double *buf, u_long a, u_long b)
 {
-  if (b < a)
+  if (b < a) {
     return 0.0;
+  }
 
   double sum = 0.0;
   for (u_long n = a; n < b; n++) {
