@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -36,6 +36,7 @@ Layer_new(Plugin_t *p)
 void
 Layer_delete(Layer_t *l)
 {
+  json_decref(l->plugin_parameters);
   xfree(l);
 }
 
@@ -44,7 +45,9 @@ Layer_t *
 Layer_copy(const Layer_t *from)
 {
   Layer_t *l = Layer_new(from->plugin);
+
   l->mode = from->mode;
+  l->plugin_parameters = json_deep_copy(from->plugin_parameters);
 
   return l;
 }
@@ -87,33 +90,33 @@ const char *
 LayerMode_to_string(const enum LayerMode mode)
 {
   switch (mode) {
-  case NONE:
-    return "none";
-    break;
+    case NONE:
+      return "none";
+      break;
 
-  case NORMAL:
-    return "normal";
-    break;
+    case NORMAL:
+      return "normal";
+      break;
 
-  case OVERLAY:
-    return "overlay";
-    break;
+    case OVERLAY:
+      return "overlay";
+      break;
 
-  case XOR:
-    return "xor";
-    break;
+    case XOR:
+      return "xor";
+      break;
 
-  case AVERAGE:
-    return "average";
-    break;
+    case AVERAGE:
+      return "average";
+      break;
 
-  case RANDOM:
-    return "random";
-    break;
+    case RANDOM:
+      return "random";
+      break;
 
-  default:
-    xerror("LayerMode_to_string: unknown mode= %d\n", mode);
-    break;
+    default:
+      xerror("LayerMode_to_string: unknown mode= %d\n", mode);
+      break;
   }
 
   return NULL; /* not reached */
