@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -216,9 +216,17 @@ main(int argc, char **argv)
 
   biniou_set_random_mode(random_mode);
 
+#ifdef WITH_ULFIUS
+  Context_start_ulfius(context);
+#endif
+
   /* Main loop */
   biniou_run();
 
+#ifdef WITH_ULFIUS
+  Context_stop_ulfius(context);
+#endif
+
   /* All done */
   biniou_delete();
 
