@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -71,6 +71,6 @@ typedef struct PluginType_s {
 } PluginType_t;
 
 
-PluginType_t pTypes[MAX_TYPES];
+extern PluginType_t pTypes[MAX_TYPES];
 
 #endif /* __BINIOU_OPTIONS_H */
