@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -100,16 +100,16 @@ Plugins_init(Plugins_t *ps)
 
       /* plugin types stuff */
       for (int t = 0; t < MAX_TYPES; t++)
-	if (*p->options & (1 << t)) {
+        if (*p->options & (1 << t)) {
 #ifdef DEBUG
-	  printf("[T] Has type %s\n", pTypes[t].name);
+          printf("[T] Has type %s\n", pTypes[t].name);
 #endif
-	  pTypes[t].count--;
-	}
+          pTypes[t].count--;
+        }
 
       if (plugins->selected == p) {
-	plugins->selected = NULL;
-	plugins->selected_idx = 0;
+        plugins->selected = NULL;
+        plugins->selected_idx = 0;
       }
       Plugin_delete(p);
       ps->plugins[i] = NULL;
@@ -219,7 +219,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
   }
   ps->plugins = xcalloc(ps->size, sizeof(Plugin_t *));
   old_size = ps->size;
-  
+
   rewinddir(da_dir);
   i = 0;
 
@@ -247,7 +247,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
     if (NULL != p) {
       if (
         ((ctx->input != NULL) ||
-        ((ctx->input == NULL) && (!(*p->options & BE_SFX2D) && !(*p->options & BE_SFX3D))))
+         ((ctx->input == NULL) && (!(*p->options & BE_SFX2D) && !(*p->options & BE_SFX3D))))
         // check if plugin needs input
         &&
         // check if plugin needs images
@@ -257,7 +257,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
         // check if plugin needs webcam
         ((ctx->webcams > 0) ||
          (!ctx->webcams && (!(*p->options & BEQ_MUTE_CAM))))
-        ) {
+      ) {
         if (libbiniou_verbose) {
           if (NULL != p->desc) {
             printf("        %s\n", p->desc);
@@ -270,13 +270,13 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
             xerror("Duplicated plugin id: %li\n", p->id);
           }
         /* plugin types stuff */
-	for (t = 0; t < MAX_TYPES; t++)
-	  if (*p->options & (1 << t)) {
+        for (t = 0; t < MAX_TYPES; t++)
+          if (*p->options & (1 << t)) {
 #ifdef DEBUG
-	    printf("[T] Has type %s\n", pTypes[t].name);
+            printf("[T] Has type %s\n", pTypes[t].name);
 #endif
-	    pTypes[t].count++;
-	  }
+            pTypes[t].count++;
+          }
 #ifdef DEBUG
         printf("\n");
 #endif
@@ -301,7 +301,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
   }
   xfree(ps->plugins);
   ps->plugins = res;
-  
+
   /* sort the plugins array */
   qsort((void *)ps->plugins, (size_t)ps->size,
         (size_t)sizeof(Plugin_t *), &Plugins_compare);
@@ -328,6 +328,20 @@ Plugins_find(const u_long id)
 }
 
 
+Plugin_t *
+Plugins_find_by_name(const char *name)
+{
+  short i;
+
+  for (i = 0; i < plugins->size; i++)
+    if (!strcmp(plugins->plugins[i]->name, name)) {
+      return plugins->plugins[i];
+    }
+
+  return NULL;
+}
+
+
 Plugin_t *
 Plugins_get_random(const enum PluginOptions feat, const Plugin_t *locked)
 {
@@ -359,7 +373,7 @@ Plugins_get_random(const enum PluginOptions feat, const Plugin_t *locked)
       retry = 1;
     } else {
       if (!ignore_beq_norandom && (*chosen->options & BEQ_NORANDOM) && (chosen != locked)) {
-	retry = 1;
+        retry = 1;
       }
     }
   } while (retry);
