@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 1994-2020 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -95,6 +95,21 @@ xrealloc(void *ptr, size_t size)
 }
 
 
+double
+xatof(const char *value)
+{
+  double f;
+
+  errno = 0;
+  f = strtod(value, NULL);
+  if (errno != 0) {
+    xperror("strtod");
+  }
+
+  return f;
+}
+
+
 long
 xatol(const char *value)
 {
